summaryrefslogtreecommitdiffstats
path: root/src/SUSE2button.h
diff options
context:
space:
mode:
authorMavridis Philippe <[email protected]>2021-06-25 19:05:29 +0300
committerMavridis Philippe <[email protected]>2021-06-25 19:15:54 +0300
commita26e231b46ac6433f6500ddc9ed6b466cf38cc21 (patch)
treeeca43ec26318abfef06040103c74ccd6f1ac02eb /src/SUSE2button.h
parentd5914d4d3223d1bca7b1b845a229af9f30466189 (diff)
downloadtwin-style-suse2-a26e231b46ac6433f6500ddc9ed6b466cf38cc21.tar.gz
twin-style-suse2-a26e231b46ac6433f6500ddc9ed6b466cf38cc21.zip
Conversion Qt3→TQt
Signed-off-by: Mavridis Philippe <[email protected]>
Diffstat (limited to 'src/SUSE2button.h')
-rw-r--r--src/SUSE2button.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/src/SUSE2button.h b/src/SUSE2button.h
index 08b2305..df83533 100644
--- a/src/SUSE2button.h
+++ b/src/SUSE2button.h
@@ -24,14 +24,14 @@
#ifndef SUSE2BUTTON_H
#define SUSE2BUTTON_H
-#include <qbutton.h>
-#include <qpixmap.h>
+#include <tqbutton.h>
+#include <tqpixmap.h>
#include <kcommondecoration.h>
#include "SUSE2.h"
-class QTimer;
+class TQTimer;
namespace KWinSUSE2 {
@@ -54,16 +54,16 @@ protected slots:
void animate();
private:
- void enterEvent(QEvent *e);
- void leaveEvent(QEvent *e);
- void drawButton(QPainter *painter);
- void drawPlastikBtn(QPainter *painter);
- void drawLipstikBtn(QPainter *painter);
- void renderBtnContour(QPainter *p, const QRect &r);
- void renderBtnSurface(QPainter *p, const QRect &r);
- void renderPixel(QPainter *p, const QPoint &pos, const int alpha, const QColor &color,
+ void enterEvent(TQEvent *e);
+ void leaveEvent(TQEvent *e);
+ void drawButton(TQPainter *painter);
+ void drawPlastikBtn(TQPainter *painter);
+ void drawLipstikBtn(TQPainter *painter);
+ void renderBtnContour(TQPainter *p, const TQRect &r);
+ void renderBtnSurface(TQPainter *p, const TQRect &r);
+ void renderPixel(TQPainter *p, const TQPoint &pos, const int alpha, const TQColor &color,
const int pixelPos, const int active);
- void renderGradient(QPainter *p, const QRect &r, const QColor &c1, const QColor &c2,
+ void renderGradient(TQPainter *p, const TQRect &r, const TQColor &c1, const TQColor &c2,
const int gradient, const int active);
@@ -73,23 +73,23 @@ private:
ButtonIcon m_iconType;
bool hover;
- QTimer *animTmr;
+ TQTimer *animTmr;
uint animProgress;
- QPixmap *lipstikCache[8+3*(ANIMATIONSTEPS+1)][2];
+ TQPixmap *lipstikCache[8+3*(ANIMATIONSTEPS+1)][2];
};
/**
* This class creates bitmaps which can be used as icons on buttons. The icons
* are "hardcoded".
* Over the previous "Gimp->xpm->QImage->recolor->SmoothScale->QPixmap" solution
* it has the important advantage that icons are more scalable and at the same
* time sharp and not blurred.
*/
class IconEngine
{
public:
- static QBitmap icon(ButtonIcon icon, int size);
+ static TQBitmap icon(ButtonIcon icon, int size);
private:
enum Object {
@@ -99,7 +99,7 @@ class IconEngine
CrossDiagonalLine
};
- static void drawObject(QPainter &p, Object object, int x, int y, int length, int lineWidth);
+ static void drawObject(TQPainter &p, Object object, int x, int y, int length, int lineWidth);
};
} // namespace KWinSUSE2
@@ -73,23 +73,23 @@ private:
* This class creates bitmaps which can be used as icons on buttons. The icons
* are "hardcoded".
- * Over the previous "Gimp->xpm->QImage->recolor->SmoothScale->QPixmap" solution
+ * Over the previous "Gimp->xpm->TQImage->recolor->SmoothScale->TQPixmap" solution
* it has the important advantage that icons are more scalable and at the same
* time sharp and not blurred.